diff src/protocols/msn/session.h @ 9158:c30d81b4dd22

[gaim-migrate @ 9942] Patch from Felipe Contreras to sync our MSN prpl with what's in his tree. He says this may fix a couple bugs, but the important thing is the restructuring of how MsnMessages work. Lots of style changes and other stuff as well. committer: Tailor Script <tailor@pidgin.im>
author Christian Hammond <chipx86@chipx86.com>
date Tue, 01 Jun 2004 06:42:20 +0000
parents bbd8cdaf0ad5
children 502707ca1836
line wrap: on
line diff
--- a/src/protocols/msn/session.h	Tue Jun 01 01:55:55 2004 +0000
+++ b/src/protocols/msn/session.h	Tue Jun 01 06:42:20 2004 +0000
@@ -40,7 +40,7 @@
 
 	guint protocol_ver;
 
-	char *dispatch_server;
+	char *dispatch_host;
 	int dispatch_port;
 
 	gboolean connected;
@@ -108,13 +108,13 @@
  * Creates an MSN session.
  *
  * @param account The account.
  * @param server  The dispatch server.
  * @param port    The dispatch port.
  *
  * @return The new MSN session.
  */
 MsnSession *msn_session_new(GaimAccount *account,
-							const char *server, int port);
+							const char *host, int port);
 
 /**
  * Destroys an MSN session.
@@ -108,13 +108,13 @@
  *
  * @param account The account.
- * @param server  The dispatch server.
- * @param port    The dispatch port.
+ * @param server  The dispatch server host.
+ * @param port    The dispatch server port.
  *
  * @return The new MSN session.